import React, { FC } from "react";
import { css } from "emotion";
import { config } from "app/core/config";
import { stylesFactory, Alert } from "@grafana/ui";

export const getStyles = stylesFactory(() => {
  const { theme } = config;

  return {
    container: css`
      position: absolute;
      bottom: 0;
      width: 100%;
      display: flex;
      flex-direction: column;
      justify-content: center;
      z-index: 1;
      box-shadow: 0 0 20px ${theme.colors.pageBg};
    `,
  };
});

interface Props {
  title: string;
  subTitle: JSX.Element;
  onCloseWarning?(): void;
}

const Warning: FC<Props> = ({ title, subTitle, onCloseWarning }) => {
  const styles = getStyles();
  const severity = onCloseWarning ? 'info' : 'error';

  return (
    <div className={styles.container}>
      <div className="page-container">
        <Alert title={title} buttonText="Dismiss" onButtonClick={onCloseWarning} severity={severity}>
          {subTitle}
        </Alert>
      </div>
    </div>
  );
};

export const HasExpired: FC = () => {
  return (
    <Warning
      title="Your Grafana Enterprise license has expired"
      subTitle={
        <>
          <a href="https://grafana.com/docs/grafana/latest/enterprise/license-expiration/" target="_blank">
            Some features
          </a>{" "}
          have been disabled{" "}
        </>
      }
    />
  );
};

interface ExpiresSoonProps {
  days: number;
  onCloseWarning?(): void;
}

export const ExpiresSoon: FC<ExpiresSoonProps> = ({ days, onCloseWarning }) => {
  return (
    <Warning
      onCloseWarning={onCloseWarning}
      title="Your Grafana Enterprise license will expire soon"
      subTitle={
        <>
          {days} days remaining, after which {" "}
          <a href="https://grafana.com/docs/grafana/latest/enterprise/license-expiration/"></a>
          <a href="https://grafana.com/docs/grafana/latest/enterprise/license-expiration/">
            Enterprise features will be disabled.
          </a>
        </>
      }
    />
  );
};
